@@ -63,19 +63,20 @@ def config_thread(logger, driver, args):
     hostname = socket.gethostname()
     logger.info("[worker] Registering task %s" % hostname)
 
-    if all([args.gearman_ssl_key, args.gearman_ssl_cert, args.gearman_ssl_ca]):
-        ssl_server_list = []
-        for host_port in args.server:
-            host, port = host_port.split(':')
-            ssl_server_list.append({'host': host,
-                                    'port': int(port),
-                                    'keyfile': args.gearman_ssl_key,
-                                    'certfile': args.gearman_ssl_cert,
-                                    'ca_certs': args.gearman_ssl_ca})
-        worker = CustomJSONGearmanWorker(ssl_server_list)
-    else:
-        worker = CustomJSONGearmanWorker(args.server)
+    server_list = []
+    for host_port in args.server:
+        host, port = host_port.split(':')
+        server_list.append({'host': host,
+                            'port': int(port),
+                            'keyfile': args.gearman_ssl_key,
+                            'certfile': args.gearman_ssl_cert,
+                            'ca_certs': args.gearman_ssl_ca,
+                            'keepalive': args.gearman_keepalive,
+                            'keepcnt': args.gearman_keepcnt,
+                            'keepidle': args.gearman_keepidle,
+                            'keepintvl': args.gearman_keepintvl})
 
+    worker = CustomJSONGearmanWorker(server_list)
     worker.set_client_id(hostname)
     worker.register_task(hostname, handler)
     worker.logger = logger
